# ksif
Data download and back testing tools for KSIF
# KSIF Preprocessing
Data preprocessing tool for KSIF library

## Usage
Set the root directory as your working directory like 'C:\Users\willbe\PycharmProjects\ksif_preprocessing'.
Pass a parameter indicating a file name in data folder like '180730'.
After running 'core/__init__.py', the result files are saved in the root directory.

## 여러가지 feature 추가 작업 재시작, daily, semi-month frequency 추가
